@@ -9,12 +9,17 @@ import json
 import os
 from dataclasses import dataclass
 from itertools import repeat
+from pathlib import Path
 from typing import Any, Dict, List, Optional, Set, Tuple
 
-import cv2
+try:
+    import cv2
+except ImportError:
+    pass  # TODO: rewrite to use PIL
+import typer
 from tqdm.contrib.concurrent import process_map
 
-import zod.annotations.parser as parser
+import zod.anno.parser as parser
 import zod.constants as constants
 from zod import ZodFrames
 from zod.data_classes.frame import ZodFrame
@@ -33,6 +38,32 @@ Images are saved in the following folder structure:
 """
 
 
+def cli_dummy(
+    dataset_root: Path = typer.Option(
+        ...,
+        exists=True,
+        dir_okay=True,
+        writable=False,
+        readable=True,
+        resolve_path=True,
+        help="Path to the root of the ZOD dataset.",
+    ),
+    output_dir: Path = typer.Option(
+        ...,
+        exists=True,
+        file_okay=False,
+        dir_okay=True,
+        writable=True,
+        readable=True,
+        resolve_path=True,
+        help="Path to the output directory.",
+    ),
+    version: str = typer.Option("full", help="Version of the dataset to use. One of: full, small."),
+    path_size: Tuple[int, int] = typer.Option((64, 64), help="Path resultion."),
+):
+    typer.echo("Not Implemented Yet")
+
+
 @dataclass
 class Args:
     """Script args."""
@@ -43,6 +74,7 @@ class Args:
     padding_factor: Optional[float]
     padding_px: Optional[Tuple[int, int]]
     overwrite: bool
+    exclude_unclear: bool
 
 
 def _parse_args():
@@ -77,6 +109,11 @@ def _parse_args():
         action="store_true",
         help="Whether to overwrite existing files.",
     )
+    parser.add_argument(
+        "--exclude-unclear",
+        action="store_true",
+        help="Whether to exclude unclear traffic signs.",
+    )
 
     args = parser.parse_args()
 
@@ -102,15 +139,17 @@ def _process_frame(frame: ZodFrame, args: Args, train_ids: Set[str]) -> List[Dic
     image_path = frame.info.get_key_camera_frame(constants.Anonymization.BLUR).filepath
     image = cv2.cvtColor(cv2.imread(image_path), cv2.COLOR_BGR2RGB)
     for traffic_sign in traffic_signs:
-        cls_name = traffic_sign.traffic_sign_class
-        train_or_val = constants.TRAIN if frame.frame_id in train_ids else constants.VAL
+        if args.exclude_unclear and traffic_sign.unclear:
+            continue
+        cls_name = "unclear" if traffic_sign.unclear else traffic_sign.traffic_sign_class
+        train_or_val = constants.TRAIN if frame.info.id in train_ids else constants.VAL
         cls_folder = os.path.join(args.output_folder, train_or_val, cls_name)
 
         if not os.path.exists(cls_folder):
             os.makedirs(cls_folder)
             os.chmod(cls_folder, 0o775)
 
-        new_frame_id = f"{frame.frame_id}_{traffic_sign.uuid}"
+        new_frame_id = f"{frame.info.id}_{traffic_sign.uuid}"
         output_file = os.path.join(
             cls_folder,
             f"{new_frame_id}.png",
@@ -170,8 +209,9 @@ def main(args: Args):
 
     traffic_sign_frames = process_map(
         _process_frame,
-        zod_frames.get_all_frames().values(),
+        zod_frames,
         repeat(args),
+        repeat(zod_frames.get_split(constants.TRAIN)),
         desc="Processing frames in ZOD",
         max_workers=args.num_workers,
         chunksize=1 if args.num_workers == 1 else 100,
