@@ -1,10 +1,14 @@
+from typing import List
+
 import numpy as np
 import typer
 from rich import print
 from rich.panel import Panel
 
 from zod import ZodFrames, ZodSequences
+from zod.constants import AnnotationProject
 from zod.data_classes import LidarData
+from zod.data_classes.box import Box3D
 from zod.utils.utils import zfill_id
 
 app = typer.Typer(no_args_is_help=True)
@@ -15,7 +19,7 @@ IMPORT_ERROR = (
 )
 
 
-def _visualize(data: LidarData):
+def _visualize(data: LidarData, boxes: List[Box3D] = None):
     try:
         import open3d as o3d
     except ImportError:
@@ -31,10 +35,23 @@ def _visualize(data: LidarData):
     color = np.log(data.intensity)
     # use a nice colormap
     pcd.colors = o3d.utility.Vector3dVector(cm.get_cmap("jet")(color)[:, :3])
-    # Draw coordinate frame
-    o3d.visualization.draw_geometries(
-        [pcd, o3d.geometry.TriangleMesh.create_coordinate_frame(size=1.0)]
-    )
+
+    # if boxes are provided, render them as rigid bodies
+    if boxes:
+        o3d_boxes = []
+        for box in boxes:
+            o3d_box = o3d.geometry.OrientedBoundingBox.create_from_points(
+                o3d.utility.Vector3dVector(box.corners)
+            )
+            o3d_box.color = (0.98, 0.63, 0.01)
+            o3d_boxes.append(o3d_box)
+        o3d.visualization.draw_geometries(
+            [pcd, *o3d_boxes, o3d.geometry.TriangleMesh.create_coordinate_frame(size=1.0)]
+        )
+    else:
+        o3d.visualization.draw_geometries(
+            [pcd, o3d.geometry.TriangleMesh.create_coordinate_frame(size=1.0)]
+        )
 
 
 @app.command(no_args_is_help=True)
@@ -44,6 +61,9 @@ def frames(
     frame_id: int = typer.Option(..., help="Frame id to visualize"),
     num_before: int = typer.Option(0, help="Number of frames before the given frame id"),
     num_after: int = typer.Option(0, help="Number of frames after the given frame id"),
+    with_bounding_boxes: bool = typer.Option(
+        False, help="if bounding boxes of center-frame are to be rendered"
+    ),
 ):
     """Visualize the lidar data for a given frame id."""
     zod_frames = ZodFrames(dataset_root=dataset_root, version=version)
@@ -51,7 +71,12 @@ def frames(
         raise ValueError(f"Frame id must be one of {zod_frames.get_all_ids()}.")
     frame = zod_frames[frame_id]
     data = frame.get_aggregated_lidar(num_before=num_before, num_after=num_after)
-    _visualize(data)
+    if with_bounding_boxes:
+        annos = frame.get_annotation(project=AnnotationProject.OBJECT_DETECTION)
+        boxes = [anno.box3d for anno in annos if anno.box3d is not None]
+    else:
+        boxes = []
+    _visualize(data, boxes=boxes)
 
 
 @app.command(no_args_is_help=True)
