@@ -6,9 +6,9 @@ from zod.constants import AnnotationProject, Anonymization, Camera, Lidar
 from zod.utils.compensation import motion_compensate_scanwise
 
 from .calibration import Calibration
+from .ego_motion import EgoMotion
 from .info import Information
 from .metadata import FrameMetaData
-from .oxts import EgoMotion
 from .sensor import CameraFrame, LidarData, LidarFrame
 
 
@@ -50,8 +50,8 @@ class ZodFrame:
 
     def get_annotation(self, project: AnnotationProject) -> List[Any]:
         """Get the annotation for a given project."""
-        assert project in self.info.annotation_frames, f"Project {project} not available."
-        return self.info.get_key_annotation_frame(project).read()
+        assert project in self.info.annotations, f"Project {project} not available."
+        return self.info.annotations[project].read()
 
     def get_camera_frame(self, anonymization: Anonymization = Anonymization.BLUR) -> CameraFrame:
         """Get the camera frame."""
